@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Aug 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,13 +24,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KID3CLI_H
-#define KID3CLI_H
+#pragma once
 
 #include "abstractcli.h"
-#include "taggedfile.h"
-#include "trackdata.h"
+#include "frame.h"
 #include "cliconfig.h"
+#ifdef HAVE_READLINE
+#include <QScopedPointer>
+#endif
 
 class QTimer;
 class Kid3Application;
@@ -51,20 +52,22 @@ public:
    * Constructor.
    * @param app application context
    * @param io I/O handler
+   * @param args command line arguments
    * @param parent parent object
    */
   explicit Kid3Cli(Kid3Application* app,
-                   AbstractCliIO* io, QObject* parent = 0);
+                   AbstractCliIO* io, const QStringList& args,
+                   QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~Kid3Cli();
+  virtual ~Kid3Cli() override;
 
   /**
    * Execute process.
    */
-  virtual void execute();
+  virtual void execute() override;
 
   /**
    * Access to application.
@@ -152,12 +155,17 @@ public slots:
    */
   void updateSelection();
 
+  /**
+   * Called when a command is finished.
+   */
+  void onCommandFinished();
+
 protected:
   /**
    * Process command line.
    * @param line command line
    */
-  virtual void readLine(const QString& line);
+  virtual void readLine(const QString& line) override;
 
 private slots:
   /**
@@ -166,11 +174,6 @@ private slots:
    */
   void onInitialDirectoryOpened();
 
-  /**
-   * Called when a command is finished.
-   */
-  void onCommandFinished();
-
   /**
    * Called when an argument command is finished.
    */
@@ -190,8 +193,9 @@ private:
   void executeNextArgCommand();
 
   Kid3Application* m_app;
+  QStringList m_args;
 #ifdef HAVE_READLINE
-  Kid3CliCompleter* m_completer;
+  QScopedPointer<Kid3CliCompleter> m_completer;
 #endif
   QList<CliCommand*> m_cmds;
   QStringList m_argCommands;
@@ -203,5 +207,3 @@ private:
   int m_timeoutMs;
   bool m_fileNameChanged;
 };
-
-#endif // KID3CLI_H
