@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,6 +26,7 @@
 
 #include "importconfig.h"
 #include <QString>
+#include "isettings.h"
 #include "config.h"
 
 namespace {
@@ -56,14 +57,14 @@ int ImportConfig::s_index = -1;
 /**
  * Constructor.
  */
-ImportConfig::ImportConfig() :
-  StoredConfig<ImportConfig>(QLatin1String("Import")), m_importServer(0),
-  m_importDest(Frame::TagV1), m_importFormatIdx(0),
-  m_maxTimeDifference(3),
-  m_importVisibleColumns(0x2000000000ULL),
-  m_importTagsIdx(0),
-  m_pictureSourceIdx(0),
-  m_enableTimeDifferenceCheck(true)
+ImportConfig::ImportConfig()
+  : StoredConfig<ImportConfig>(QLatin1String("Import")), m_importServer(0),
+    m_importDest(Frame::TagV1), m_importFormatIdx(0),
+    m_maxTimeDifference(3),
+    m_importVisibleColumns(0x2000000000ULL),
+    m_importTagsIdx(0),
+    m_pictureSourceIdx(0),
+    m_enableTimeDifferenceCheck(true)
 {
   /**
    * Preset import format regular expressions.
@@ -85,16 +86,25 @@ ImportConfig::ImportConfig() :
    */
   m_importFormatNames.append(QLatin1String("CSV unquoted"));
   m_importFormatHeaders.append(QLatin1String(""));
-  m_importFormatTracks.append(QLatin1String("%{track}(\\d+)\\t%{title}([^\\r\\n\\t]*)\\t%{artist}([^\\r\\n\\t]*)\\t%{album}([^\\r\\n\\t]*)\\t%{year}([^\\r\\n\\t]*)\\t%{genre}([^\\r\\n\\t]*)\\t%{comment}([^\\r\\n\\t]*)\\t(?:\\d+:)?%{duration}(\\d+:\\d+)"));
+  m_importFormatTracks.append(QLatin1String(
+    R"(%{track}([^\r\n\t]*)\t%{title}([^\r\n\t]*)\t%{artist}([^\r\n\t]*)\t)"
+    R"(%{album}([^\r\n\t]*)\t%{year}([^\r\n\t]*)\t%{genre}([^\r\n\t]*)\t)"
+    R"(%{comment}([^\r\n\t]*)\t(?:\d+:)?%{duration}(\d+:\d+))"));
 
   m_importFormatNames.append(QLatin1String("CSV quoted"));
   m_importFormatHeaders.append(QLatin1String(""));
-  m_importFormatTracks.append(QLatin1String("\"?%{track}(\\d+)\"?\\t\"?%{title}([^\\r\\n\\t\"]*)\"?\\t\"?%{artist}([^\\r\\n\\t\"]*)\"?\\t\"?%{album}([^\\r\\n\\t\"]*)\"?\\t\"?%{year}([^\\r\\n\\t]*)\"?\\t\"?%{genre}([^\\r\\n\\t\"]*)\"?\\t\"?%{comment}([^\\r\\n\\t\"]*)\"?\\t\"?(?:\\d+:)?%{duration}(\\d+:\\d+)"));
+  // Using a raw string literal here causes clang to issue
+  // "Unbalanced opening parenthesis in C++ code".
+  m_importFormatTracks.append(QLatin1String(
+    "\"?%{track}([^\\r\\n\\t\"]*)\"?\\t\"?%{title}([^\\r\\n\\t\"]*)\"?\\t\"?"
+    "%{artist}([^\\r\\n\\t\"]*)\"?\\t\"?%{album}([^\\r\\n\\t\"]*)\"?"
+    "\\t\"?%{year}([^\\r\\n\\t\"]*)\"?\\t\"?%{genre}([^\\r\\n\\t\"]*)\"?"
+    "\\t\"?%{comment}([^\\r\\n\\t\"]*)\"?\\t\"?(?:\\d+:)?%{duration}(\\d+:\\d+)"));
 
   m_importFormatNames.append(QLatin1String("CSV more unquoted"));
   m_importFormatHeaders.append(QLatin1String(""));
   m_importFormatTracks.append(QLatin1String(
-    "%{track}(\\d+)\\t%{title}([^\\r\\n\\t]*)\\t%{artist}([^\\r\\n\\t]*)\\t"
+    "%{track}([^\\r\\n\\t]*)\\t%{title}([^\\r\\n\\t]*)\\t%{artist}([^\\r\\n\\t]*)\\t"
     "%{album}([^\\r\\n\\t]*)\\t%{year}([^\\r\\n\\t]*)\\t%{genre}([^\\r\\n\\t]*)\\"
     "t%{comment}([^\\r\\n\\t]*)\\t(?:\\d+:)?%{duration}(\\d+:\\d+)(?:\\.\\d+)?\\t"
     "%{album artist}([^\\r\\n\\t]*)\\t%{arranger}([^\\r\\n\\t]*)\\t"
@@ -112,17 +122,19 @@ ImportConfig::ImportConfig() :
   m_importFormatNames.append(QLatin1String("CSV more quoted"));
   m_importFormatHeaders.append(QLatin1String(""));
   m_importFormatTracks.append(QLatin1String(
-    "\"?%{track}(\\d+)\"?\\t\"?%{title}([^\\r\\n\\t\"]*)\"?\\t"
+    "\"?%{track}([^\\r\\n\\t\"]*)\"?\\t\"?%{title}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{artist}([^\\r\\n\\t\"]*)\"?\\t\"?%{album}([^\\r\\n\\t\"]*)\"?\\t"
-    "\"?%{year}([^\\r\\n\\t]*)\"?\\t\"?%{genre}([^\\r\\n\\t\"]*)\"?\\t"
+    "\"?%{year}([^\\r\\n\\t\"]*)\"?\\t\"?%{genre}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{comment}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?(?:\\d+:)?%{duration}(\\d+:\\d+)(?:\\.\\d+)?\"?\\t"
     "\"?%{album artist}([^\\r\\n\\t\"]*)\"?\\t\"?%{arranger}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{author}([^\\r\\n\\t\"]*)\"?\\t\"?%{bpm}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{composer}([^\\r\\n\\t\"]*)\"?\\t\"?%{conductor}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{copyright}([^\\r\\n\\t\"]*)\"?\\t\"?%{disc number}([^\\r\\n\\t\"]*)\"?\\t"
-    "\"?%{encoded-by}([^\\r\\n\\t\"]*)\"?\\t\"?%{grouping}([^\\r\\n\\t\"]*)\"?\\t\"?%{isrc}([^\\r\\n\\t\"]*)\"?\\t"
-    "\"?%{language}([^\\r\\n\\t\"]*)\"?\\t\"?%{lyricist}([^\\r\\n\\t\"]*)\"?\\t\"?%{lyrics}([^\\r\\n\\t\"]*)\"?\\t"
+    "\"?%{encoded-by}([^\\r\\n\\t\"]*)\"?\\t\"?%{grouping}([^\\r\\n\\t\"]*)\"?\\t"
+    "\"?%{isrc}([^\\r\\n\\t\"]*)\"?\\t"
+    "\"?%{language}([^\\r\\n\\t\"]*)\"?\\t\"?%{lyricist}([^\\r\\n\\t\"]*)\"?\\t"
+    "\"?%{lyrics}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{media}([^\\r\\n\\t\"]*)\"?\\t\"?%{original album}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{original artist}([^\\r\\n\\t\"]*)\"?\\t\"?%{original date}([^\\r\\n\\t\"]*)\"?\\t"
     "\"?%{part}([^\\r\\n\\t\"]*)\"?\\t\"?%{performer}([^\\r\\n\\t\"]*)\"?\\t"
@@ -130,24 +142,36 @@ ImportConfig::ImportConfig() :
     "\"?%{subtitle}([^\\r\\n\\t\"]*)\"?\\t\"?%{website}([^\\r\\n\\t\"]*)"));
 
   m_importFormatNames.append(QLatin1String("freedb HTML text"));
-  m_importFormatHeaders.append(QLatin1String("%{artist}(\\S[^\\r\\n/]*\\S)\\s*/\\s*%{album}(\\S[^\\r\\n]*\\S)[\\r\\n]+\\s*tracks:\\s+\\d+.*year:\\s*%{year}([^\\r\\n\\t]*)?.*genre:\\s*%{genre}(\\S[^\\r\\n]*\\S)?[\\r\\n]"));
-  m_importFormatTracks.append(QLatin1String("[\\r\\n]%{track}(\\d+)[\\.\\s]+%{duration}(\\d+:\\d+)\\s+%{title}(\\S[^\\r\\n]*\\S)"));
+  m_importFormatHeaders.append(QLatin1String(
+    R"(%{artist}(\S[^\r\n/]*\S)\s*/\s*%{album}(\S[^\r\n]*\S)[\r\n]+\s*)"
+    R"(tracks:\s+\d+.*year:\s*%{year}([^\r\n\t]*)?.*)"
+    R"(genre:\s*%{genre}(\S[^\r\n]*\S)?[\r\n])"));
+  m_importFormatTracks.append(QLatin1String(
+    R"([\r\n]%{track}(\d+)[\.\s]+%{duration}(\d+:\d+)\s+%{title}(\S[^\r\n]*\S))"));
 
   m_importFormatNames.append(QLatin1String("freedb HTML source"));
-  m_importFormatHeaders.append(QLatin1String("<[^>]+>%{artist}([^<\\s][^\\r\\n/]*\\S)\\s*/\\s*%{album}(\\S[^\\r\\n]*[^\\s>])<[^>]+>[\\r\\n]+\\s*tracks:\\s+\\d+.*year:\\s*%{year}([^\\r\\n\\t]*)?.*genre:\\s*%{genre}(\\S[^\\r\\n>]*\\S)?<[^>]+>[\\r\\n]"));
-  m_importFormatTracks.append(QLatin1String("<td[^>]*>\\s*%{track}(\\d+).</td><td[^>]*>\\s*%{duration}(\\d+:\\d+)</td><td[^>]*>(?:<[^>]+>)?%{title}([^<\\r\\n]+)"));
+  m_importFormatHeaders.append(QLatin1String(
+    R"(<[^>]+>%{artist}([^<\s][^\r\n/]*\S)\s*/\s*)"
+    R"(%{album}(\S[^\r\n]*[^\s>])<[^>]+>[\r\n]+\s*)"
+    R"(tracks:\s+\d+.*year:\s*%{year}([^\r\n\t]*)?.*)"
+    R"(genre:\s*%{genre}(\S[^\r\n>]*\S)?<[^>]+>[\r\n])"));
+  m_importFormatTracks.append(QLatin1String(
+    R"(<td[^>]*>\s*%{track}(\d+).</td><td[^>]*>\s*%{duration}(\d+:\d+)</td>)"
+    R"(<td[^>]*>(?:<[^>]+>)?%{title}([^<\r\n]+))"));
 
   m_importFormatNames.append(QLatin1String("Title"));
   m_importFormatHeaders.append(QLatin1String(""));
-  m_importFormatTracks.append(QLatin1String("\\s*%{title}(\\S[^\\r\\n]*\\S)\\s*"));
+  m_importFormatTracks.append(QLatin1String(R"(\s*%{title}(\S[^\r\n]*\S)\s*)"));
 
   m_importFormatNames.append(QLatin1String("Track Title"));
   m_importFormatHeaders.append(QLatin1String(""));
-  m_importFormatTracks.append(QLatin1String("\\s*%{track}(\\d+)[\\.\\s]+%{title}(\\S[^\\r\\n]*\\S)\\s*"));
+  m_importFormatTracks.append(QLatin1String(
+    R"(\s*%{track}(\d+)[\.\s]+%{title}(\S[^\r\n]*\S)\s*)"));
 
   m_importFormatNames.append(QLatin1String("Track Title Time"));
   m_importFormatHeaders.append(QLatin1String(""));
-  m_importFormatTracks.append(QLatin1String("\\s*%{track}(\\d+)[\\.\\s]+%{title}(\\S[^\\r\\n]*\\S)\\s+%{duration}(\\d+:\\d+)\\s*"));
+  m_importFormatTracks.append(QLatin1String(
+    R"(\s*%{track}(\d+)[\.\s]+%{title}(\S[^\r\n]*\S)\s+%{duration}(\d+:\d+)\s*)"));
 
   m_importFormatNames.append(QLatin1String("Custom Format"));
   m_importFormatHeaders.append(QLatin1String(""));
@@ -171,7 +195,8 @@ ImportConfig::ImportConfig() :
 
   m_importTagsNames.append(QLatin1String("Track Number from Title"));
   m_importTagsSources.append(QLatin1String("%{title}"));
-  m_importTagsExtractions.append(QLatin1String("\\s*%{track}(\\d+)[\\.\\s]+%{title}(\\S.*\\S)\\s*"));
+  m_importTagsExtractions.append(
+        QLatin1String(R"(\s*%{track}(\d+)[\.\s]+%{title}(\S.*\S)\s*)"));
 
   m_importTagsNames.append(QLatin1String("Track Number to Title"));
   m_importTagsSources.append(QLatin1String("%{track} %{title}"));
@@ -183,36 +208,49 @@ ImportConfig::ImportConfig() :
 
   m_importTagsNames.append(QLatin1String("Title Annotation to Comment"));
   m_importTagsSources.append(QLatin1String("%{title}"));
-  m_importTagsExtractions.append(QLatin1String("%{title}(.+) +\\(%{comment}((?:Bonus|Remix)[^)]*)\\)"));
+  m_importTagsExtractions.append(
+        QLatin1String("%{title}(.+) +\\(%{comment}((?:Bonus|Remix)[^)]*)\\)"));
 
   m_importTagsNames.append(QLatin1String("Custom Format"));
   m_importTagsSources.append(QLatin1String(""));
   m_importTagsExtractions.append(QLatin1String(""));
 
   m_pictureSourceNames.append(QLatin1String("Google Images"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.google.com/search?tbm=isch&q=%u{artist}%20%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.google.com/search?tbm=isch&q=%u{artist}%20%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Yahoo Images"));
-  m_pictureSourceUrls.append(QLatin1String("http://images.search.yahoo.com/search/images?ei=UTF-8&p=%u{artist}%20%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://images.search.yahoo.com/search/images?ei=UTF-8&p=%u{artist}%20%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Amazon"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.amazon.com/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.amazon.com/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Amazon.co.uk"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.amazon.co.uk/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.amazon.co.uk/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Amazon.de"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.amazon.de/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.amazon.de/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Amazon.fr"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.amazon.fr/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.amazon.fr/s?search-alias=aps&field-keywords=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("MusicBrainz"));
-  m_pictureSourceUrls.append(QLatin1String("http://musicbrainz.org/search/textsearch.html?query=%u{artist}+%u{album}&type=release"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://musicbrainz.org/search/textsearch.html?query=%u{artist}+%u{album}&type=release"));
   m_pictureSourceNames.append(QLatin1String("Discogs"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.discogs.com/search?q=%u{artist}+%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.discogs.com/search?q=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("CD Universe"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.cduniverse.com/sresult.asp?HT_Search_Info=%u{artist}+%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.cduniverse.com/sresult.asp?HT_Search_Info=%u{artist}+%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Coveralia"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.coveralia.com/mostrar.php?bus=%u{artist}%20%u{album}&bust=2"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.coveralia.com/mostrar.php?bus=%u{artist}%20%u{album}&bust=2"));
   m_pictureSourceNames.append(QLatin1String("SlothRadio"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.slothradio.com/covers/?artist=%u{artist}&album=%u{album}"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.slothradio.com/covers/?artist=%u{artist}&album=%u{album}"));
   m_pictureSourceNames.append(QLatin1String("Albumart"));
-  m_pictureSourceUrls.append(QLatin1String("http://www.albumart.org/index.php?srchkey=%u{artist}+%u{album}&searchindex=Music"));
+  m_pictureSourceUrls.append(QLatin1String(
+    "http://www.albumart.org/index.php?srchkey=%u{artist}+%u{album}&searchindex=Music"));
   m_pictureSourceNames.append(QLatin1String("Custom Source"));
   m_pictureSourceUrls.append(QLatin1String(""));
 
@@ -220,19 +258,16 @@ ImportConfig::ImportConfig() :
     QLatin1String("\\1");
   m_matchPictureUrlMap[QLatin1String("http://images.search.yahoo.com/.*&imgurl=([^&]+)&.*")] =
     QLatin1String("http%3A%2F%2F\\1");
-  m_matchPictureUrlMap[QLatin1String("http://(?:www.)?amazon.(?:com|co.uk|de|fr).*/(?:dp|ASIN|images|product|-)/([A-Z0-9]+).*")] =
+  m_matchPictureUrlMap[QLatin1String(
+    "http://(?:www.)?amazon.(?:com|co.uk|de|fr).*/(?:dp|ASIN|images|product|-)/([A-Z0-9]+).*")] =
     QLatin1String("http://images.amazon.com/images/P/\\1.01._SCLZZZZZZZ_.jpg");
-  m_matchPictureUrlMap[QLatin1String("http://musicbrainz.org/misc/redirects/.*&asin=([A-Z0-9]+).*")] =
+  m_matchPictureUrlMap[QLatin1String(
+    "http://musicbrainz.org/misc/redirects/.*&asin=([A-Z0-9]+).*")] =
     QLatin1String("http://images.amazon.com/images/P/\\1.01._SCLZZZZZZZ_.jpg");
   m_matchPictureUrlMap[QLatin1String("(http://.*4shared.com/img/.*)")] =
     QLatin1String("\\1.jpg");
 }
 
-/**
- * Destructor.
- */
-ImportConfig::~ImportConfig() {}
-
 /**
  * Persist configuration.
  *
@@ -241,36 +276,57 @@ ImportConfig::~ImportConfig() {}
 void ImportConfig::writeToConfig(ISettings* config) const
 {
   config->beginGroup(m_group);
-  config->setValue(QLatin1String("ImportServer"), QVariant(m_importServer));
+  config->setValue(QLatin1String("ImportServer"),
+                   QVariant(m_importServer));
   config->setValue(QLatin1String("ImportDestination"),
                    QVariant(tagVersionToImportDestCfg(m_importDest)));
-  config->setValue(QLatin1String("ImportFormatNames"), QVariant(m_importFormatNames));
-  config->setValue(QLatin1String("ImportFormatHeaders"), QVariant(m_importFormatHeaders));
-  config->setValue(QLatin1String("ImportFormatTracks"), QVariant(m_importFormatTracks));
-  config->setValue(QLatin1String("ImportFormatIdx"), QVariant(m_importFormatIdx));
-  config->setValue(QLatin1String("EnableTimeDifferenceCheck"), QVariant(m_enableTimeDifferenceCheck));
-  config->setValue(QLatin1String("MaxTimeDifference"), QVariant(m_maxTimeDifference));
+  config->setValue(QLatin1String("ImportFormatNames"),
+                   QVariant(m_importFormatNames));
+  config->setValue(QLatin1String("ImportFormatHeaders"),
+                   QVariant(m_importFormatHeaders));
+  config->setValue(QLatin1String("ImportFormatTracks"),
+                   QVariant(m_importFormatTracks));
+  config->setValue(QLatin1String("ImportFormatIdx"),
+                   QVariant(m_importFormatIdx));
+  config->setValue(QLatin1String("EnableTimeDifferenceCheck"),
+                   QVariant(m_enableTimeDifferenceCheck));
+  config->setValue(QLatin1String("MaxTimeDifference"),
+                   QVariant(m_maxTimeDifference));
 #ifdef Q_OS_MAC
   // Convince Mac OS X to store a 64-bit value.
-  config->setValue(QLatin1String("ImportVisibleColumns"), QVariant(m_importVisibleColumns | (Q_UINT64_C(1) << 63)));
+  config->setValue(QLatin1String("ImportVisibleColumns"),
+                   QVariant(m_importVisibleColumns | (Q_UINT64_C(1) << 63)));
 #else
-  config->setValue(QLatin1String("ImportVisibleColumns"), QVariant(m_importVisibleColumns));
+  config->setValue(QLatin1String("ImportVisibleColumns"),
+                   QVariant(m_importVisibleColumns));
 #endif
-  config->setValue(QLatin1String("ImportWindowGeometry"), QVariant(m_importWindowGeometry));
+  config->setValue(QLatin1String("ImportWindowGeometry"),
+                   QVariant(m_importWindowGeometry));
 
-  config->setValue(QLatin1String("ImportTagsNames"), QVariant(m_importTagsNames));
-  config->setValue(QLatin1String("ImportTagsSources"), QVariant(m_importTagsSources));
-  config->setValue(QLatin1String("ImportTagsExtractions"), QVariant(m_importTagsExtractions));
-  config->setValue(QLatin1String("ImportTagsIdx"), QVariant(m_importTagsIdx));
+  config->setValue(QLatin1String("ImportTagsNames"),
+                   QVariant(m_importTagsNames));
+  config->setValue(QLatin1String("ImportTagsSources"),
+                   QVariant(m_importTagsSources));
+  config->setValue(QLatin1String("ImportTagsExtractions"),
+                   QVariant(m_importTagsExtractions));
+  config->setValue(QLatin1String("ImportTagsIdx"),
+                   QVariant(m_importTagsIdx));
 
-  config->setValue(QLatin1String("PictureSourceNames"), QVariant(m_pictureSourceNames));
-  config->setValue(QLatin1String("PictureSourceUrls"), QVariant(m_pictureSourceUrls));
-  config->setValue(QLatin1String("PictureSourceIdx"), QVariant(m_pictureSourceIdx));
-  config->setValue(QLatin1String("MatchPictureUrlMapKeys"), QVariant(m_matchPictureUrlMap.keys()));
-  config->setValue(QLatin1String("MatchPictureUrlMapValues"), QVariant(m_matchPictureUrlMap.values()));
-  config->setValue(QLatin1String("BrowseCoverArtWindowGeometry"), QVariant(m_browseCoverArtWindowGeometry));
+  config->setValue(QLatin1String("PictureSourceNames"),
+                   QVariant(m_pictureSourceNames));
+  config->setValue(QLatin1String("PictureSourceUrls"),
+                   QVariant(m_pictureSourceUrls));
+  config->setValue(QLatin1String("PictureSourceIdx"),
+                   QVariant(m_pictureSourceIdx));
+  config->setValue(QLatin1String("MatchPictureUrlMapKeys"),
+                   QVariant(m_matchPictureUrlMap.keys()));
+  config->setValue(QLatin1String("MatchPictureUrlMapValues"),
+                   QVariant(m_matchPictureUrlMap.values()));
+  config->setValue(QLatin1String("BrowseCoverArtWindowGeometry"),
+                   QVariant(m_browseCoverArtWindowGeometry));
 
-  config->setValue(QLatin1String("DisabledPlugins"), QVariant(m_disabledPlugins));
+  config->setValue(QLatin1String("DisabledPlugins"),
+                   QVariant(m_disabledPlugins));
   config->endGroup();
 }
 
@@ -286,39 +342,56 @@ void ImportConfig::readFromConfig(ISettings* config)
   QStringList picNames, picUrls;
 
   config->beginGroup(m_group);
-  m_importServer = config->value(QLatin1String("ImportServer"), m_importServer).toInt();
+  m_importServer = config->value(QLatin1String("ImportServer"),
+                                 m_importServer).toInt();
   m_importDest = importDestCfgToTagVersion(
     config->value(QLatin1String("ImportDestination"),
                   tagVersionToImportDestCfg(m_importDest)).toInt());
-  names = config->value(QLatin1String("ImportFormatNames"), m_importFormatNames).toStringList();
-  headers = config->value(QLatin1String("ImportFormatHeaders"), m_importFormatHeaders).toStringList();
-  tracks = config->value(QLatin1String("ImportFormatTracks"), m_importFormatTracks).toStringList();
-  m_importFormatIdx = config->value(QLatin1String("ImportFormatIdx"), m_importFormatIdx).toInt();
-  m_enableTimeDifferenceCheck = config->value(QLatin1String("EnableTimeDifferenceCheck"), m_enableTimeDifferenceCheck).toBool();
-  m_maxTimeDifference = config->value(QLatin1String("MaxTimeDifference"), m_maxTimeDifference).toInt();
-  m_importVisibleColumns = config->value(QLatin1String("ImportVisibleColumns"), m_importVisibleColumns).toULongLong();
+  names = config->value(QLatin1String("ImportFormatNames"),
+                        m_importFormatNames).toStringList();
+  headers = config->value(QLatin1String("ImportFormatHeaders"),
+                          m_importFormatHeaders).toStringList();
+  tracks = config->value(QLatin1String("ImportFormatTracks"),
+                         m_importFormatTracks).toStringList();
+  m_importFormatIdx = config->value(QLatin1String("ImportFormatIdx"),
+                                    m_importFormatIdx).toInt();
+  m_enableTimeDifferenceCheck =
+      config->value(QLatin1String("EnableTimeDifferenceCheck"),
+                    m_enableTimeDifferenceCheck).toBool();
+  m_maxTimeDifference = config->value(QLatin1String("MaxTimeDifference"),
+                                      m_maxTimeDifference).toInt();
+  m_importVisibleColumns = config->value(QLatin1String("ImportVisibleColumns"),
+                                         m_importVisibleColumns).toULongLong();
 #ifdef Q_OS_MAC
   m_importVisibleColumns &= ~(Q_UINT64_C(1) << 63);
 #endif
-  m_importWindowGeometry = config->value(QLatin1String("ImportWindowGeometry"), m_importWindowGeometry).toByteArray();
+  m_importWindowGeometry = config->value(QLatin1String("ImportWindowGeometry"),
+                                         m_importWindowGeometry).toByteArray();
 
-  tagsNames = config->value(QLatin1String("ImportTagsNames"), m_importTagsNames).toStringList();
-  tagsSources = config->value(QLatin1String("ImportTagsSources"), m_importTagsSources).toStringList();
-  tagsExtractions = config->value(QLatin1String("ImportTagsExtractions"), m_importTagsExtractions).toStringList();
-  m_importTagsIdx = config->value(QLatin1String("ImportTagsIdx"), m_importTagsIdx).toInt();
+  tagsNames = config->value(QLatin1String("ImportTagsNames"),
+                            m_importTagsNames).toStringList();
+  tagsSources = config->value(QLatin1String("ImportTagsSources"),
+                              m_importTagsSources).toStringList();
+  tagsExtractions = config->value(QLatin1String("ImportTagsExtractions"),
+                                  m_importTagsExtractions).toStringList();
+  m_importTagsIdx = config->value(QLatin1String("ImportTagsIdx"),
+                                  m_importTagsIdx).toInt();
 
-  picNames = config->value(QLatin1String("PictureSourceNames"), m_pictureSourceNames).toStringList();
-  picUrls = config->value(QLatin1String("PictureSourceUrls"), m_pictureSourceUrls).toStringList();
+  picNames = config->value(QLatin1String("PictureSourceNames"),
+                           m_pictureSourceNames).toStringList();
+  picUrls = config->value(QLatin1String("PictureSourceUrls"),
+                          m_pictureSourceUrls).toStringList();
   m_pictureSourceIdx = config->value(
     QLatin1String("PictureSourceIdx"), m_pictureSourceIdx).toInt();
-  QStringList keys = config->value(QLatin1String("MatchPictureUrlMapKeys"), QStringList()).toStringList();
-  QStringList values = config->value(QLatin1String("MatchPictureUrlMapValues"), QStringList()).toStringList();
+  QStringList keys = config->value(QLatin1String("MatchPictureUrlMapKeys"),
+                                   QStringList()).toStringList();
+  QStringList values = config->value(QLatin1String("MatchPictureUrlMapValues"),
+                                     QStringList()).toStringList();
   if (!keys.empty() && !values.empty()) {
-    QStringList::Iterator itk, itv;
     m_matchPictureUrlMap.clear();
-    for (itk = keys.begin(), itv = values.begin();
-       itk != keys.end() && itv != values.end();
-       ++itk, ++itv) {
+    for (auto itk = keys.constBegin(), itv = values.constBegin();
+         itk != keys.constEnd() && itv != values.constEnd();
+         ++itk, ++itv) {
       m_matchPictureUrlMap[*itk] = *itv;
     }
   }
@@ -339,11 +412,10 @@ void ImportConfig::readFromConfig(ISettings* config)
   while (picUrls.size() < numPicNames) picUrls.append(QLatin1String(""));
 
   /* Use defaults if no configuration found */
-  QStringList::const_iterator namesIt, headersIt, tracksIt;
-  for (namesIt = names.begin(), headersIt = headers.begin(),
-         tracksIt = tracks.begin();
-       namesIt != names.end() && headersIt != headers.end() &&
-         tracksIt != tracks.end();
+  for (auto namesIt = names.constBegin(), headersIt = headers.constBegin(),
+         tracksIt = tracks.constBegin();
+       namesIt != names.constEnd() && headersIt != headers.constEnd() &&
+         tracksIt != tracks.constEnd();
        ++namesIt, ++headersIt, ++tracksIt) {
     int idx = m_importFormatNames.indexOf(*namesIt);
     if (idx >= 0) {
@@ -356,11 +428,10 @@ void ImportConfig::readFromConfig(ISettings* config)
     }
   }
 
-  QStringList::const_iterator tagsNamesIt, sourcesIt, extractionsIt;
-  for (tagsNamesIt = tagsNames.begin(), sourcesIt = tagsSources.begin(),
-         extractionsIt = tagsExtractions.begin();
-       tagsNamesIt != tagsNames.end() && sourcesIt != tagsSources.end() &&
-         extractionsIt != tagsExtractions.end();
+  for (auto tagsNamesIt = tagsNames.constBegin(), sourcesIt = tagsSources.constBegin(),
+         extractionsIt = tagsExtractions.constBegin();
+       tagsNamesIt != tagsNames.constEnd() && sourcesIt != tagsSources.constEnd() &&
+         extractionsIt != tagsExtractions.constEnd();
        ++tagsNamesIt, ++sourcesIt, ++extractionsIt) {
     int idx = m_importTagsNames.indexOf(*tagsNamesIt);
     if (idx >= 0) {
@@ -373,9 +444,8 @@ void ImportConfig::readFromConfig(ISettings* config)
     }
   }
 
-  QStringList::const_iterator picNamesIt, picUrlsIt;
-  for (picNamesIt = picNames.begin(), picUrlsIt = picUrls.begin();
-       picNamesIt != picNames.end() && picUrlsIt != picUrls.end();
+  for (auto picNamesIt = picNames.constBegin(), picUrlsIt = picUrls.constBegin();
+       picNamesIt != picNames.constEnd() && picUrlsIt != picUrls.constEnd();
        ++picNamesIt, ++picUrlsIt) {
     int idx = m_pictureSourceNames.indexOf(*picNamesIt);
     if (idx >= 0) {
@@ -428,7 +498,7 @@ void ImportConfig::readFromConfig(ISettings* config)
   m_matchPictureUrlMap.remove(QLatin1String(
       "http://rds.yahoo.com/.*%26imgurl=((?:[^%]|%(?!26))+).*"));
   m_matchPictureUrlMap.remove(QLatin1String(
-      "http://cdbaby.com/cd/(\\w)(\\w)(\\w+)"));
+      R"(http://cdbaby.com/cd/(\w)(\w)(\w+))"));
   m_matchPictureUrlMap.remove(QLatin1String(
       "http://www.jamendo.com/en/album/(\\d+)"));
 }
@@ -590,9 +660,7 @@ QVariantMap ImportConfig::matchPictureUrlVariantMap() const
 {
   QVariantMap map;
   QMap<QString, QString> urlMap = matchPictureUrlMap();
-  for (QMap<QString, QString>::const_iterator it = urlMap.constBegin();
-       it != urlMap.constEnd();
-       ++it) {
+  for (auto it = urlMap.constBegin(); it != urlMap.constEnd(); ++it) {
     map.insert(it.key(), it.value());
   }
   return map;
@@ -601,9 +669,7 @@ QVariantMap ImportConfig::matchPictureUrlVariantMap() const
 void ImportConfig::setMatchPictureUrlVariantMap(const QVariantMap& map)
 {
   QMap<QString, QString> urlMap;
-  for (QVariantMap::const_iterator it = map.constBegin();
-       it != map.constEnd();
-       ++it) {
+  for (auto it = map.constBegin(); it != map.constEnd(); ++it) {
     urlMap.insert(it.key(), it.value().toString());
   }
   setMatchPictureUrlMap(urlMap);
