@@ -47,6 +47,8 @@ QHash<int,QByteArray> getRoleHash()
   roles[FrameTableModel::InternalNameRole] = "internalName";
   roles[FrameTableModel::FieldIdsRole] = "fieldIds";
   roles[FrameTableModel::FieldValuesRole] = "fieldValues";
+  roles[FrameTableModel::CompletionsRole] = "completions";
+  roles[FrameTableModel::NoticeRole] = "notice";
   return roles;
 }
 
@@ -106,7 +108,7 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
   }
   if (((role == Qt::BackgroundColorRole || role == Qt::ToolTipRole) &&
        index.column() == CI_Value) ||
-      role == TruncatedRole) {
+      (role == TruncatedRole || role == NoticeRole)) {
     isTruncated = (static_cast<unsigned>(index.row()) < sizeof(m_markedRows) * 8 &&
         (m_markedRows & (1ULL << index.row())) != 0) || it->isMarked();
   }
@@ -175,6 +177,18 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
       result.append(fit->m_value);
     }
     return result;
+  } else if (role == CompletionsRole) {
+    QStringList result = getCompletionsForType(it->getExtendedType()).toList();
+    result.sort();
+    return result;
+  } else if (role == NoticeRole) {
+    QString toolTip;
+    if (isTruncated) {
+      FrameNotice notice = it->isMarked() ? it->getNotice()
+                                          : FrameNotice::Truncated;
+      toolTip = notice.getDescription();
+    }
+    return toolTip;
   }
   return QVariant();
 }
