@@ -47,7 +47,9 @@ public:
     TruncatedRole =  Qt::UserRole + 5,
     InternalNameRole =  Qt::UserRole + 6,
     FieldIdsRole =  Qt::UserRole + 7,
-    FieldValuesRole =  Qt::UserRole + 8
+    FieldValuesRole =  Qt::UserRole + 8,
+    CompletionsRole =  Qt::UserRole + 9,
+    NoticeRole =  Qt::UserRole + 10
   };
 
   /** Column indices. */
