@@ -256,6 +256,12 @@ public:
    */
   QList<ServerImporter*> getServerImporters() { return m_importers; }
 
+  /**
+   * Get names of available server track importers.
+   * @return list of server track importer names.
+   */
+  Q_INVOKABLE QStringList getServerImporterNames() const;
+
   /**
    * Get available server track importers.
    * @return list of server track importers.
@@ -1605,6 +1611,9 @@ private:
   PixmapProvider* m_imageProvider;
   QString m_coverArtImageId;
 
+#ifdef Q_OS_ANDROID
+  bool m_pendingIntentsChecked;
+#endif
 #ifdef HAVE_QTDBUS
   /** true if D-Bus is enabled */
   bool m_dbusEnabled;
