@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Sep 2005
  *
- * Copyright (C) 2005-2013  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,11 +27,7 @@
 #include "taggedfile.h"
 #include <QDir>
 #include <QString>
-#if QT_VERSION >= 0x050100
 #include <QRegularExpression>
-#else
-#include <QRegExp>
-#endif
 #ifdef Q_OS_WIN32
 #include <sys/types.h>
 #include <sys/utime.h>
@@ -50,8 +46,8 @@
  *
  * @param idx index in file proxy model
  */
-TaggedFile::TaggedFile(const QPersistentModelIndex& idx) :
-  m_index(idx), m_truncation(0), m_modified(false), m_marked(false)
+TaggedFile::TaggedFile(const QPersistentModelIndex& idx)
+  : m_index(idx), m_truncation(0), m_modified(false), m_marked(false)
 {
   FOR_ALL_TAGS(tagNr) {
     m_changedFrames[tagNr] = 0;
@@ -64,13 +60,6 @@ TaggedFile::TaggedFile(const QPersistentModelIndex& idx) :
   }
 }
 
-/**
- * Destructor.
- */
-TaggedFile::~TaggedFile()
-{
-}
-
 /**
  * Get file proxy model.
  * @return file proxy model.
@@ -106,6 +95,23 @@ void TaggedFile::setFilename(const QString& fn)
   updateModifiedState();
 }
 
+/**
+ * Update the current filename after the file was renamed.
+ */
+void TaggedFile::updateCurrentFilename()
+{
+  if (const FileProxyModel* model = getFileProxyModel()) {
+    const QString newName = model->fileName(m_index);
+    if (!newName.isEmpty() && m_filename != newName) {
+      if (m_newFilename == m_filename) {
+        m_newFilename = newName;
+      }
+      m_filename = newName;
+      updateModifiedState();
+    }
+  }
+}
+
 /**
  * Get current path to file.
  * @return absolute path.
@@ -163,7 +169,7 @@ void TaggedFile::deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt)
   Frame frame;
   frame.setValue(QLatin1String(""));
   for (int i = Frame::FT_FirstFrame; i <= Frame::FT_LastV1Frame; ++i) {
-    Frame::Type type = static_cast<Frame::Type>(i);
+    auto type = static_cast<Frame::Type>(i);
     if (flt.isEnabled(type)) {
       frame.setExtendedType(Frame::ExtendedType(type));
       setFrame(tagNr, frame);
@@ -332,6 +338,9 @@ void TaggedFile::notifyTruncationChanged(bool priorTruncation) const
   }
 }
 
+
+namespace {
+
 /**
  * Remove artist part from album string.
  * This is used when only the album is needed, but the regexp in
@@ -341,7 +350,7 @@ void TaggedFile::notifyTruncationChanged(bool priorTruncation) const
  *
  * @return album with artist removed.
  */
-static QString removeArtist(const QString& album)
+QString removeArtist(const QString& album)
 {
   QString str(album);
   int pos = str.indexOf(QLatin1String(" - "));
@@ -351,6 +360,8 @@ static QString removeArtist(const QString& album)
   return str;
 }
 
+}
+
 /**
  * Get tags from filename.
  * Supported formats:
@@ -372,18 +383,8 @@ static QString removeArtist(const QString& album)
  */
 void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt)
 {
-/** @cond */
-#if QT_VERSION >= 0x050100
   QRegularExpression re;
   QRegularExpressionMatch match;
-#define re_hasMatch(s) (match = re.match(s)).hasMatch()
-#define re_cap(i) match.captured(i)
-#else
-  QRegExp re;
-#define re_hasMatch(s) re.indexIn(s) != -1
-#define re_cap(i) re.cap(i)
-#endif
-/** @endcond */
   QString fn(getAbsFilename());
 
   // construct regular expression from format string
@@ -433,9 +434,9 @@ void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt
   const QString prefix(QLatin1String(useCustomCaptures ? "%{" : "%\\{"));
   const QString suffix(QLatin1String(useCustomCaptures ? "}"  : "\\}"));
   const int prefixLen = prefix.length();
-  for (unsigned i = 0; i < sizeof(codeToName) / sizeof(codeToName[0]); ++i) {
-    QString from = QString::fromLatin1(codeToName[i].from);
-    QString to = QString::fromLatin1(codeToName[i].to);
+  for (const auto& c2n : codeToName) {
+    QString from = QString::fromLatin1(c2n.from);
+    QString to = QString::fromLatin1(c2n.to);
     from = from.size() == 1 ? QLatin1Char('%') + from : prefix + from + suffix;
     to = prefix + to + suffix;
     pattern.replace(from, to);
@@ -473,12 +474,10 @@ void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt
   pattern += QLatin1String("\\..{2,4}$");
 
   re.setPattern(pattern);
-  if (re_hasMatch(fileName)) {
-    for (QMap<QString, int>::iterator it = codePos.begin();
-         it != codePos.end();
-         ++it) {
-      QString name = it.key();
-      QString str = re_cap(*it);
+  if ((match = re.match(fileName)).hasMatch()) {
+    for (auto it = codePos.begin(); it != codePos.end(); ++it) {
+      const QString& name = it.key();
+      QString str = match.captured(*it);
       if (!str.isEmpty()) {
         if (!useCustomCaptures && name == QLatin1String("track number") &&
             str.length() == 2 && str[0] == QLatin1Char('0')) {
@@ -493,68 +492,79 @@ void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt
   }
 
   // album/track - artist - song
-  re.setPattern(QLatin1String("([^/]+)/(\\d{1,3})[-_\\. ]+([^-_\\./ ][^/]+)[_ ]-[_ ]([^-_\\./ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setAlbum(removeArtist(re_cap(1)));
-    frames.setTrack(re_cap(2).toInt());
-    frames.setArtist(re_cap(3));
-    frames.setTitle(re_cap(4));
+  re.setPattern(QLatin1String(
+    R"(([^/]+)/(\d{1,3})[-_\. ]+([^-_\./ ][^/]+)[_ ]-[_ ])"
+    R"(([^-_\./ ][^/]+)\..{2,4}$)"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setAlbum(removeArtist(match.captured(1)));
+    frames.setTrack(match.captured(2).toInt());
+    frames.setArtist(match.captured(3));
+    frames.setTitle(match.captured(4));
     return;
   }
 
   // artist - album (year)/track song
-  re.setPattern(QLatin1String("([^/]+)[_ ]-[_ ]([^/]+)[_ ]\\((\\d{4})\\)/(\\d{1,3})[-_\\. ]+([^-_\\./ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setArtist(re_cap(1));
-    frames.setAlbum(re_cap(2));
-    frames.setYear(re_cap(3).toInt());
-    frames.setTrack(re_cap(4).toInt());
-    frames.setTitle(re_cap(5));
+  re.setPattern(QLatin1String(
+    R"(([^/]+)[_ ]-[_ ]([^/]+)[_ ]\((\d{4})\)/(\d{1,3})[-_\. ]+)"
+    R"(([^-_\./ ][^/]+)\..{2,4}$)"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setArtist(match.captured(1));
+    frames.setAlbum(match.captured(2));
+    frames.setYear(match.captured(3).toInt());
+    frames.setTrack(match.captured(4).toInt());
+    frames.setTitle(match.captured(5));
     return;
   }
 
   // artist - album/track song
-  re.setPattern(QLatin1String("([^/]+)[_ ]-[_ ]([^/]+)/(\\d{1,3})[-_\\. ]+([^-_\\./ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setArtist(re_cap(1));
-    frames.setAlbum(re_cap(2));
-    frames.setTrack(re_cap(3).toInt());
-    frames.setTitle(re_cap(4));
+  re.setPattern(QLatin1String(
+    R"(([^/]+)[_ ]-[_ ]([^/]+)/(\d{1,3})[-_\. ]+([^-_\./ ][^/]+)\..{2,4}$)"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setArtist(match.captured(1));
+    frames.setAlbum(match.captured(2));
+    frames.setTrack(match.captured(3).toInt());
+    frames.setTitle(match.captured(4));
     return;
   }
   // /artist - album - track - song
-  re.setPattern(QLatin1String("/([^/]+[^-_/ ])[_ ]-[_ ]([^-_/ ][^/]+[^-_/ ])[-_\\. ]+(\\d{1,3})[-_\\. ]+([^-_\\./ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setArtist(re_cap(1));
-    frames.setAlbum(re_cap(2));
-    frames.setTrack(re_cap(3).toInt());
-    frames.setTitle(re_cap(4));
+  re.setPattern(QLatin1String(
+    R"(/([^/]+[^-_/ ])[_ ]-[_ ]([^-_/ ][^/]+[^-_/ ])[-_\. ]+)"
+    R"((\d{1,3})[-_\. ]+([^-_\./ ][^/]+)\..{2,4}$)"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setArtist(match.captured(1));
+    frames.setAlbum(match.captured(2));
+    frames.setTrack(match.captured(3).toInt());
+    frames.setTitle(match.captured(4));
     return;
   }
   // album/artist - track - song
-  re.setPattern(QLatin1String("([^/]+)/([^/]+[^-_\\./ ])[-_\\. ]+(\\d{1,3})[-_\\. ]+([^-_\\./ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setAlbum(removeArtist(re_cap(1)));
-    frames.setArtist(re_cap(2));
-    frames.setTrack(re_cap(3).toInt());
-    frames.setTitle(re_cap(4));
+  re.setPattern(QLatin1String(
+    R"(([^/]+)/([^/]+[^-_\./ ])[-_\. ]+(\d{1,3})[-_\. ]+)"
+    R"(([^-_\./ ][^/]+)\..{2,4}$)"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setAlbum(removeArtist(match.captured(1)));
+    frames.setArtist(match.captured(2));
+    frames.setTrack(match.captured(3).toInt());
+    frames.setTitle(match.captured(4));
     return;
   }
   // artist/album/track song
-  re.setPattern(QLatin1String("([^/]+)/([^/]+)/(\\d{1,3})[-_\\. ]+([^-_\\./ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setArtist(re_cap(1));
-    frames.setAlbum(re_cap(2));
-    frames.setTrack(re_cap(3).toInt());
-    frames.setTitle(re_cap(4));
+  re.setPattern(QLatin1String(
+    R"(([^/]+)/([^/]+)/(\d{1,3})[-_\. ]+([^-_\./ ][^/]+)\..{2,4}$)"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setArtist(match.captured(1));
+    frames.setAlbum(match.captured(2));
+    frames.setTrack(match.captured(3).toInt());
+    frames.setTitle(match.captured(4));
     return;
   }
   // album/artist - song
-  re.setPattern(QLatin1String("([^/]+)/([^/]+[^-_/ ])[_ ]-[_ ]([^-_/ ][^/]+)\\..{2,4}$"));
-  if (re_hasMatch(fn)) {
-    frames.setAlbum(removeArtist(re_cap(1)));
-    frames.setArtist(re_cap(2));
-    frames.setTitle(re_cap(3));
+  re.setPattern(QLatin1String(
+    "([^/]+)/([^/]+[^-_/ ])[_ ]-[_ ]([^-_/ ][^/]+)\\..{2,4}$"));
+  if ((match = re.match(fn)).hasMatch()) {
+    frames.setAlbum(removeArtist(match.captured(1)));
+    frames.setArtist(match.captured(2));
+    frames.setTitle(match.captured(3));
     return;
   }
 }
@@ -586,15 +596,15 @@ QString TaggedFile::formatTime(unsigned seconds)
 /**
  * Rename a file.
  * This methods takes care of case insensitive filesystems.
- *
- * @param fnOld old filename
- * @param fnNew new filename
- *
  * @return true if ok.
  */
-bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
+bool TaggedFile::renameFile() const
 {
-  QString dirname = getDirname();
+  const QString dirname = getDirname();
+  const QString fnOld = currentFilename();
+  const QString fnNew = getFilename();
+  auto model = const_cast<FileProxyModel*>(getFileProxyModel());
+
   if (fnNew.toLower() == fnOld.toLower()) {
     // If the filenames only differ in case, the new file is reported to
     // already exist on case insensitive filesystems (e.g. Windows),
@@ -603,8 +613,10 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
     // another file would be overwritten and an error is reported.
     if (QFile::exists(dirname + QDir::separator() + fnNew)) {
       struct stat statOld, statNew;
-      if (::stat((dirname + QDir::separator() + fnOld).toLatin1().data(), &statOld) == 0 &&
-          ::stat((dirname + QDir::separator() + fnNew).toLatin1().data(), &statNew) == 0 &&
+      if (::stat((dirname + QDir::separator() + fnOld).toLatin1().data(),
+                 &statOld) == 0 &&
+          ::stat((dirname + QDir::separator() + fnNew).toLatin1().data(),
+                 &statNew) == 0 &&
           !(statOld.st_ino == statNew.st_ino &&
             statOld.st_dev == statNew.st_dev)) {
         qDebug("rename(%s, %s): %s already exists", fnOld.toLatin1().data(),
@@ -618,12 +630,14 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
     // insensitive filesystems (e.g. Windows).
     QString temp_filename(fnNew);
     temp_filename.append(QLatin1String("_CASE"));
-    if (!Utils::safeRename(dirname, fnOld, temp_filename)) {
+    if (!((model && model->rename(m_index, temp_filename)) ||
+          Utils::safeRename(dirname, fnOld, temp_filename))) {
       qDebug("rename(%s, %s) failed", fnOld.toLatin1().data(),
              temp_filename.toLatin1().data());
       return false;
     }
-    if (!Utils::safeRename(dirname, temp_filename, fnNew)) {
+    if (!((model && model->rename(m_index, fnNew)) ||
+          Utils::safeRename(dirname, temp_filename, fnNew))) {
       qDebug("rename(%s, %s) failed", temp_filename.toLatin1().data(),
              fnNew.toLatin1().data());
       return false;
@@ -632,7 +646,8 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
     qDebug("rename(%s, %s): %s already exists", fnOld.toLatin1().data(),
            fnNew.toLatin1().data(), fnNew.toLatin1().data());
     return false;
-  } else if (!Utils::safeRename(dirname, fnOld, fnNew)) {
+  } else if (!((model && model->rename(m_index, fnNew)) ||
+               Utils::safeRename(dirname, fnOld, fnNew))) {
     qDebug("rename(%s, %s) failed", fnOld.toLatin1().data(),
            fnNew.toLatin1().data());
     return false;
@@ -670,8 +685,8 @@ int TaggedFile::splitNumberAndTotal(const QString& str, int* total)
     return str.toInt();
 
   if (total)
-    *total = str.mid(slashPos + 1).toInt();
-  return str.left(slashPos).toInt();
+    *total = str.midRef(slashPos + 1).toInt();
+  return str.leftRef(slashPos).toInt();
 }
 
 /**
@@ -922,10 +937,10 @@ void TaggedFile::updateMarkedState(Frame::TagNumber tagNr,
   }
 
   if (tagCfg.markOversizedPictures()) {
-    FrameCollection::const_iterator it =
+    auto it =
         frames.findByExtendedType(Frame::ExtendedType(Frame::FT_Picture));
-    while (it != frames.end() && it->getType() == Frame::FT_Picture) {
-      Frame& frame = const_cast<Frame&>(*it);
+    while (it != frames.cend() && it->getType() == Frame::FT_Picture) {
+      auto& frame = const_cast<Frame&>(*it);
       if (FrameNotice::addPictureTooLargeNotice(
             frame, tagCfg.maximumPictureSize())) {
         m_marked = true;
@@ -969,9 +984,7 @@ void TaggedFile::setFrames(Frame::TagNumber tagNr,
                            const FrameCollection& frames, bool onlyChanged)
 {
   if (tagNr == Frame::Tag_Id3v1) {
-    for (FrameCollection::const_iterator it = frames.begin();
-         it != frames.end();
-         ++it) {
+    for (auto it = frames.cbegin(); it != frames.cend(); ++it) {
       if (!onlyChanged || it->isValueChanged()) {
         setFrame(tagNr, *it);
       }
@@ -981,9 +994,7 @@ void TaggedFile::setFrames(Frame::TagNumber tagNr,
     FrameCollection myFrames;
     QSet<int> replacedIndexes;
 
-    for (FrameCollection::const_iterator it = frames.begin();
-         it != frames.end();
-         ++it) {
+    for (auto it = frames.cbegin(); it != frames.cend(); ++it) {
       if (!onlyChanged || it->isValueChanged()) {
         if (it->getIndex() != -1) {
           // The frame has an index, so the original tag can be modified
@@ -999,7 +1010,7 @@ void TaggedFile::setFrames(Frame::TagNumber tagNr,
               getAllFrames(tagNr, myFrames);
               myFramesValid = true;
             }
-            FrameCollection::iterator myIt = myFrames.find(*it);
+            auto myIt = myFrames.find(*it);
             int myIndex = -1;
             while (myIt != myFrames.end() && !(*it < *myIt) &&
                    (myIndex = myIt->getIndex()) != -1) {
@@ -1101,16 +1112,9 @@ bool TaggedFile::setFileTimeStamps(const QString& path,
 /**
  * Constructor.
  */
-TaggedFile::DetailInfo::DetailInfo() :
-  channelMode(CM_None), channels(0), sampleRate(0), bitrate(0), duration(0),
-  valid(false), vbr(false)
-{
-}
-
-/**
- * Destructor.
- */
-TaggedFile::DetailInfo::~DetailInfo()
+TaggedFile::DetailInfo::DetailInfo()
+  : channelMode(CM_None), channels(0), sampleRate(0), bitrate(0), duration(0),
+    valid(false), vbr(false)
 {
 }
 
