@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Sep 2005
  *
- * Copyright (C) 2005-2011  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TAGGEDFILE_H
-#define TAGGEDFILE_H
+#pragma once
 
 #include <QString>
 #include <QStringList>
@@ -59,8 +58,6 @@ public:
 
     /** Constructor. */
     DetailInfo();
-    /** Destructor. */
-    ~DetailInfo();
 
     QString format;          /**< format description */
     ChannelMode channelMode; /**< channel mode */
@@ -88,7 +85,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~TaggedFile();
+  virtual ~TaggedFile() = default;
 
   /**
    * Set file name.
@@ -371,6 +368,11 @@ public:
    */
   void undoRevertChangedFilename();
 
+  /**
+   * Update the current filename after the file was renamed.
+   */
+  void updateCurrentFilename();
+
   /**
    * Check if tag was changed.
    * @param tagNr tag number
@@ -476,7 +478,7 @@ public:
    *
    * @return number, 0 if parsing failed, -1 if str is null
    */
-  static int splitNumberAndTotal(const QString& str, int* total=0);
+  static int splitNumberAndTotal(const QString& str, int* total=nullptr);
 
   /**
    * Get access and modification time of file.
@@ -507,13 +509,9 @@ protected:
   /**
    * Rename a file.
    * This methods takes care of case insensitive filesystems.
-   *
-   * @param fnOld old filename
-   * @param fnNew new filename
-   *
    * @return true if ok.
    */
-  bool renameFile(const QString& fnOld, const QString& fnNew) const;
+  bool renameFile() const;
 
   /**
    * Get field name for comment from configuration.
@@ -656,5 +654,3 @@ private:
   /** true if tagged file is marked */
   bool m_marked;
 };
-
-#endif // TAGGEDFILE_H
