@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jun 2009
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,24 +24,23 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EDITFRAMEFIELDSDIALOG_H
-#define EDITFRAMEFIELDSDIALOG_H
+#pragma once
 
 #include <QDialog>
 #include <QLabel>
-#include "frame.h"
 #include <QList>
+#include "frame.h"
 
 class QVBoxLayout;
 class TaggedFile;
 class IPlatformTools;
 class Kid3Application;
+class FieldControl;
 
 /** Row of buttons to load, save and view binary data */
 class BinaryOpenSave : public QWidget {
- Q_OBJECT
-
- public:
+  Q_OBJECT
+public:
   /**
    * Constructor.
    *
@@ -90,7 +89,7 @@ class BinaryOpenSave : public QWidget {
    */
   void setFilter(const QString& filter) { m_filter = filter; }
 
- public slots:
+public slots:
   /**
    * Enable the "From Clipboard" button if the clipboard contains an image.
    */
@@ -122,7 +121,7 @@ class BinaryOpenSave : public QWidget {
    */
   void viewData();
 
- private:
+private:
   IPlatformTools* m_platformTools;
   Kid3Application* m_app;
   /** Array with binary data */
@@ -142,38 +141,9 @@ class BinaryOpenSave : public QWidget {
 };
 
 
-/** Base class for field controls */
-class FieldControl : public QObject {
-public:
-  /**
-   * Constructor.
-   */
-  FieldControl() {}
-
-  /**
-   * Destructor.
-   */
-  virtual ~FieldControl();
-
-  /**
-   * Update field from data in field control.
-   */
-  virtual void updateTag() = 0;
-
-  /**
-   * Create widget to edit field data.
-   *
-   * @param parent parent widget
-   *
-   * @return widget to edit field data.
-   */
-  virtual QWidget* createWidget(QWidget* parent) = 0;
-};
-
-
 /** Field edit dialog */
 class EditFrameFieldsDialog : public QDialog {
-Q_OBJECT
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -183,12 +153,12 @@ public:
    * @param parent     parent widget
    */
   EditFrameFieldsDialog(IPlatformTools* platformTools, Kid3Application* app,
-                        QWidget* parent = 0);
+                        QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~EditFrameFieldsDialog();
+  virtual ~EditFrameFieldsDialog() override;
 
   /**
    * Set frame to edit.
@@ -224,5 +194,3 @@ private:
   Frame::Field m_valueField;
   QList<FieldControl*> m_fieldcontrols;
 };
-
-#endif // EDITFRAMEFIELDSDIALOG_H
