@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 20 Jun 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -41,53 +41,43 @@
  * @param trackDataModel track data to be filled with imported values
  */
 TagImportDialog::TagImportDialog(QWidget* parent,
-                                 TrackDataModel* trackDataModel) :
-  QDialog(parent), m_trackDataModel(trackDataModel)
+                                 TrackDataModel* trackDataModel)
+  : QDialog(parent), m_trackDataModel(trackDataModel)
 {
   setObjectName(QLatin1String("TagImportDialog"));
   setWindowTitle(tr("Import from Tags"));
   setSizeGripEnabled(true);
 
-  QVBoxLayout* vboxLayout = new QVBoxLayout(this);
+  auto vboxLayout = new QVBoxLayout(this);
 
   m_formatListEdit = new FormatListEdit(
-        QStringList() << tr("Format:")
-                      << tr("Source:")
-                      << tr("Extraction:"),
-        QStringList() << QString()
-                      << TrackDataFormatReplacer::getToolTip()
-                      << ImportParser::getFormatToolTip(),
+        {tr("Format:"), tr("Source:"), tr("Extraction:")},
+        {QString(), TrackDataFormatReplacer::getToolTip(),
+         ImportParser::getFormatToolTip()},
         this);
   vboxLayout->addWidget(m_formatListEdit);
 
-  QHBoxLayout* buttonLayout = new QHBoxLayout;
+  auto buttonLayout = new QHBoxLayout;
   QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   buttonLayout->addWidget(helpButton);
-  connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
+  connect(helpButton, &QAbstractButton::clicked, this, &TagImportDialog::showHelp);
   QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   buttonLayout->addWidget(saveButton);
-  connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
+  connect(saveButton, &QAbstractButton::clicked, this, &TagImportDialog::saveConfig);
   buttonLayout->addStretch();
   QPushButton* applyButton = new QPushButton(tr("&Apply"), this);
   applyButton->setAutoDefault(false);
   buttonLayout->addWidget(applyButton);
-  connect(applyButton, SIGNAL(clicked()), this, SLOT(apply()));
+  connect(applyButton, &QAbstractButton::clicked, this, &TagImportDialog::apply);
   QPushButton* closeButton = new QPushButton(tr("&Close"), this);
   closeButton->setAutoDefault(false);
   buttonLayout->addWidget(closeButton);
-  connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
+  connect(closeButton, &QAbstractButton::clicked, this, &QDialog::accept);
   vboxLayout->addLayout(buttonLayout);
 }
 
-/**
- * Destructor.
- */
-TagImportDialog::~TagImportDialog()
-{
-}
-
 /**
  * Clear dialog data.
  */
@@ -116,9 +106,8 @@ void TagImportDialog::setFormatFromConfig()
 {
   const ImportConfig& importCfg = ImportConfig::instance();
   m_formatListEdit->setFormats(
-        QList<QStringList>() << importCfg.importTagsNames()
-                             << importCfg.importTagsSources()
-                             << importCfg.importTagsExtractions(),
+        {importCfg.importTagsNames(), importCfg.importTagsSources(),
+         importCfg.importTagsExtractions()},
         importCfg.importTagsIndex());
 }
 
