@@ -35,6 +35,8 @@
 #include <QBuffer>
 #include <QCryptographicHash>
 #include <QJSEngine>
+#include <QStandardPaths>
+#include <QStorageInfo>
 #include "pictureframe.h"
 #include "saferename.h"
 #include "mainwindowconfig.h"
@@ -238,6 +240,28 @@ bool ScriptUtils::fileExists(const QString& filePath)
   return QFile::exists(filePath);
 }
 
+/**
+ * @brief Get type of file.
+ * @param filePath path to file
+ * @return "/" for directories, "@" for symlinks, "*" for executables,
+ *         " " for files.
+ */
+QString ScriptUtils::classifyFile(const QString& filePath)
+{
+  QFileInfo fi(filePath);
+  if (fi.isSymLink()) {
+    return QLatin1String("@");
+  } else if (fi.isDir()) {
+    return QLatin1String("/");
+  } else if (fi.isExecutable()) {
+    return QLatin1String("*");
+  } else if (fi.isFile()) {
+    return QLatin1String(" ");
+  } else {
+    return QString();
+  }
+}
+
 /**
  * Rename file.
  * @param oldName old name
@@ -289,6 +313,46 @@ QString ScriptUtils::tempPath()
   return QDir::tempPath();
 }
 
+/**
+ * Get directory containing the user's music.
+ * @return music directory.
+ */
+QString ScriptUtils::musicPath()
+{
+  return QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
+}
+
+/**
+ * Get list of currently mounted filesystems.
+ * @return list with storage information maps containing the keys
+ * name, displayName, isValid, isReadOnly, isReady, rootPath,
+ * blockSize, mbytesAvailable, mbytesFree, mbytesTotal.
+ */
+QVariantList ScriptUtils::mountedVolumes()
+{
+  QVariantList result;
+  for (const QStorageInfo& si : QStorageInfo::mountedVolumes()) {
+    QVariantMap map;
+    map.insert(QLatin1String("name"), si.name());
+    map.insert(QLatin1String("displayName"), si.displayName());
+    map.insert(QLatin1String("isValid"), si.isValid());
+    map.insert(QLatin1String("isReadOnly"), si.isReadOnly());
+    map.insert(QLatin1String("isReady"), si.isReady());
+    map.insert(QLatin1String("rootPath"), si.rootPath());
+#if QT_VERSION >= 0x050600
+    map.insert(QLatin1String("blockSize"), si.blockSize());
+#endif
+    map.insert(QLatin1String("mbytesAvailable"),
+               static_cast<int>(si.bytesAvailable() / (1024 * 1024)));
+    map.insert(QLatin1String("mbytesFree"),
+               static_cast<int>(si.bytesFree() / (1024 * 1024)));
+    map.insert(QLatin1String("mbytesTotal"),
+               static_cast<int>(si.bytesTotal() / (1024 * 1024)));
+    result.append(map);
+  }
+  return result;
+}
+
 /**
  * List directory entries.
  * @param path directory path
