@@ -177,6 +177,14 @@ public:
    */
   Q_INVOKABLE static bool fileExists(const QString& filePath);
 
+  /**
+   * @brief Get type of file.
+   * @param filePath path to file
+   * @return "/" for directories, "@" for symlinks, "*" for executables,
+   *         " " for files.
+   */
+  Q_INVOKABLE static QString classifyFile(const QString& filePath);
+
   /**
    * Rename file.
    * @param oldName old name
@@ -215,6 +223,20 @@ public:
    */
   Q_INVOKABLE static QString tempPath();
 
+  /**
+   * Get directory containing the user's music.
+   * @return music directory.
+   */
+  Q_INVOKABLE static QString musicPath();
+
+  /**
+   * Get list of currently mounted filesystems.
+   * @return list with storage information maps containing the keys
+   * name, displayName, isValid, isReadOnly, isReady, rootPath,
+   * blockSize, mbytesAvailable, mbytesFree, mbytesTotal.
+   */
+  Q_INVOKABLE QVariantList mountedVolumes();
+
   /**
    * List directory entries.
    * @param path directory path
